#
# spec file for package cabal-install
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with tests
Name:           cabal-install
Version:        2.2.0.0
Release:        2.1
Summary:        The command-line interface for Cabal and Hackage
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{name}-%{version}/revision/1.cabal#/%{name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-HTTP-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cryptohash-sha256-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-echo-devel
BuildRequires:  ghc-edit-distance-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hackage-security-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-resolv-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-tar-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-zlib-devel
Suggests:       %{name}-bash-completion
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
The 'cabal' command-line program simplifies the process of managing Haskell
software by automating the fetching, configuration, compilation and
installation of Haskell libraries and programs.

This package only provides an executable and cannot be used as a library
(ignore the module listing below.).

%package bash-completion
Summary:        Bash completion for cabal-install
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    packageand(%{name}:bash-completion)

%description bash-completion
Optional sub-package offering bash completion for cabal-install.

%prep
%setup -q
cp -p %{SOURCE1} %{name}.cabal

%build
%ghc_bin_build

%install
%ghc_bin_install
install -D -m444 bash-completion/cabal %{buildroot}%{_datadir}/bash-completion/completions/cabal

%check
%cabal_test

%files
%license LICENSE
%doc README.md changelog
%{_bindir}/cabal
%{_mandir}/man1/cabal.1%{?ext_man}

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/cabal

%changelog
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update cabal-install to version 2.2.0.0 revision 1.
  * '--with-PROG' and '--PROG-options' are applied to all packages
    and not local packages only (#5019).
  * Completed the 'new-update' command (#4809), which respects nix-style
    cabal.project(.local) files and allows to update from
    multiple repositories when using overlays.
  * Completed the 'new-run' command (#4477). The functionality is the
    same of the old 'run' command but using nix-style builds.
    Additionally, it can run executables across packages in a project.
    Tests and benchmarks are also treated as executables, providing a
    quick way to pass them arguments.
  * Completed the 'new-bench' command (#3638). Same as above.
  * Completed the 'new-exec' command (#3638). Same as above.
  * Added a preliminary 'new-install' command (#4558, nonlocal exes
    part) which allows to quickly install executables from Hackage.
  * Set symlink-bindir (used by new-install) to .cabal/bin by default on
    .cabal/config initialization (#5188).
  * 'cabal update' now supports '--index-state' which can be used to
    roll back the index to an earlier state.
  * '--allow-{newer,older}' syntax has been enhanced. Dependency
    relaxation can be now limited to a specific release of a package,
    plus there's a new syntax for relaxing only caret-style (i.e. '^>=')
    dependencies (#4575, #4669).
  * New config file field: 'cxx-options' to specify which options to be
    passed to the compiler when compiling C++ sources specified by the
    'cxx-sources' field. (#3700)
  * New config file field: 'cxx-sources' to specify C++ files to be
    compiled separately from C source files. Useful in conjunction with the
    'cxx-options' flag to pass different compiler options to C and C++
    source files. (#3700)
  * Use [lfxtb] letters to differentiate component kind instead of
    opaque "c" in dist-dir layout.
  * 'cabal configure' now supports '--enable-static', which can be
    used to build static libaries with GHC via GHC's `-staticlib`
    flag.
  * 'cabal user-config now supports '--augment' which can append
    additional lines to a new or updated cabal config file.
  * Added support for '--enable-tests' and '--enable-benchmarks' to
    'cabal fetch' (#4948).
  * Misspelled package-names on CLI will no longer be silently
    case-corrected (#4778).
  * 'cabal new-configure' now backs up the old 'cabal.project.local'
    file if it exists (#4460).
  * On macOS, `new-build` will now place dynamic libraries into
    `store/lib` and aggressively shorten their names in an effort to
    stay within the load command size limits of macOSs mach-o linker.
  * 'new-build' now checks for the existence of executables for
    build-tools and build-tool-depends dependencies in the solver
    (#4884).
  * Fixed a spurious warning telling the user to run 'cabal update'
    when it wasn't necessary (#4444).
  * Packages installed in sandboxes via 'add-source' now have
    their timestamps updated correctly and so will not be reinstalled
    unncecessarily if the main install command fails (#1375).
  * Add Windows device path support for copyFile, renameFile. Allows cabal
    new-build to use temporary store path of up to 32k length
    (#3972, #4914, #4515).
  * When a flag value is specified multiple times on the command
    line, the last one is now preferred, so e.g. '-f+dev -f-dev' is
    now equivalent to '-f-dev' (#4452).
  * Removed support for building cabal-install with GHC < 7.10 (#4870).
  * New 'package *' section in 'cabal.project' files that applies
    options to all packages, not just those local to the project.
  * Paths_ autogen modules now compile when `RebindableSyntax` or
    `OverloadedStrings` is used in `default-extensions`.
    [stack#3789](https://github.com/commercialhaskell/stack/issues/3789)
  * getDataDir` and other `Paths_autogen` functions now work
    correctly when compiling a custom `Setup.hs` script using
    `new-build` (#5164).
  * Support for GHC's numeric -g debug levels (#4673).
  * Demoted 'scope' field version check to a warning (#4714).
  * Fixed verbosity flags getting removed before being passed to
    'printPlan' (#4724).
  * Added a '--store-dir' option that can be used to configure the
    location of the build global build store (#4623).
  * Turned `allow-{newer,older}` in `cabal.project` files into an
    accumulating field to match CLI flag semantics (#4679).
  * Improve success message when `cabal upload`ing documentation
    (#4777).
  * Documentation fixes.
  * See http://coldwa.st/e/blog/2017-09-09-Cabal-2-0.html
    for more detailed release notes.
  * Removed the '--root-cmd' parameter of the 'install' command
    (#3356).
  * Deprecated 'cabal install --global' (#3356).
  * Changed 'cabal upload' to upload a package candidate by default
    (#3419). Same applies to uploading documentation.
  * Added a new 'cabal upload' flag '--publish' for publishing a
    package on Hackage instead of uploading a candidate (#3419).
  * Added optional solver output visualisation support via the
    tracetree package. Mainly intended for debugging (#3410).
  * Removed the '--check' option from 'cabal upload'
    (#1823). It was replaced by package candidates.
  * Fixed various behaviour differences between network transports
    (#3429).
  * The bootstrap script now works correctly when run from a Git
    clone (#3439).
  * Removed the top-down solver (#3598).
  * The '-v/--verbosity' option no longer affects GHC verbosity
    (except in the case of '-v0'). Use '--ghc-options=-v' to enable
    verbose GHC output (#3540, #3671).
  * Changed the default logfile template from
    '.../$pkgid.log' to '.../$compiler/$libname.log' (#3807).
  * Added a new command, 'cabal reconfigure', which re-runs 'configure'
    with the most recently used flags (#2214).
  * Added the '--index-state' flag for requesting a specific
    version of the package index (#3893, #4115).
  * Support for building Backpack packages.  See
    https://github.com/ezyang/ghc-proposals/blob/backpack/proposals/0000-backpack.rst
    for more details.
  * Support the Nix package manager (#3651).
  * Made the 'template-haskell' package non-upgradable again (#4185).
  * Fixed password echoing on MinTTY (#4128).
  * Added a new solver flag, '--allow-boot-library-installs', that allows
    any package to be installed or upgraded (#4209).
  * New 'cabal-install' command: 'outdated', for listing outdated
    version bounds in a .cabal file or a freeze file (#4207).
  * Added qualified constraints for setup dependencies. For example,
  - -constraint="setup.bar == 1.0" constrains all setup dependencies on
    bar, and --constraint="foo:setup.bar == 1.0" constrains foo's setup
    dependency on bar (part of #3502).
  * Non-qualified constraints, such as --constraint="bar == 1.0", now
    only apply to top-level dependencies. They don't constrain setup or
    build-tool dependencies. The new syntax --constraint="any.bar == 1.0"
    constrains all uses of bar.
  * Added a technical preview version of the 'cabal doctest' command
    (#4480).
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sat May 27 2017 psimons@suse.com
- Update to version 1.24.0.2 revision 1.
* Wed Apr 26 2017 psimons@suse.com
- Add bash-completion sub-package that provides the auto-completion
  instructions for bash.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.24.0.2 with cabal2obs.
* Mon Nov 21 2016 psimons@suse.com
- Update to version 1.24.0.0 revision 2 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 1.24.0.0 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.22.9.0 revision 0 with cabal2obs.
* Mon Mar  7 2016 mimi.vx@gmail.com
- update to 1.22.9.0
  * Include Cabal-1.22.8.0
* Mon Feb  1 2016 mimi.vx@gmail.com
- update to 1.22.8.0
  * Only Custom setup scripts should be compiled with '-i -i.'.
  * installedCabalVersion: Don't special-case Cabal anymore.
  * Bump the HTTP upper bound.
* Sun Jan 24 2016 mimi.vx@gmail.com
- relax HTTP dep
* Mon Dec 28 2015 mimi.vx@gmail.com
- update to 1.22.7.0
  * Remove GZipUtils tests
  * maybeDecompress: bail on all errors at the beginning of the stream with zlib < 0.6
  * Correct maybeDecompress
* Wed Jul  8 2015 peter.trommler@ohm-hochschule.de
- update to 1.22.6.0
  * work with ghc 7.10
  * bug fixes
* Sun May 10 2015 mimi.vx@gmail.com
- update to 1.18.1.0
  * Force cabal upload to always use digest auth and never basic auth.
  * Merge pull request #2367 from juhp/patch-2
  * Fix bootstrap.sh by bumping HTTP to 4000.2.16.1
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 1.18.0.8
  * Support random 1.1.
  * Fix bootstrap script after network package split.
  * Support network-2.6 in test suite.
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- update to 1.18.0.4 for Haskell Platform 2014.2.0.0
  * no upstream changelog
* Mon Sep  1 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file with cabal-rpm 0.8.6
* Fri Aug 22 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Tue May  7 2013 peter.trommler@ohm-hochschule.de
- update to 1.16.0.2 from upstream
  * fix compilation issues with ghc 7.6
- part of Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- service localonly for Factory submission
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- update to 0.14.0 from upstream
- required for Haskell Platform 2012.2.0.0
* Sat Dec 31 2011 peter.trommler@ohm-hochschule.de
- Added other BR
- Fixed defattr
- Fixed filename in files
* Thu Dec  8 2011 peter.trommler@ohm-hochschule.de
- Added ghc-HTTP-devel to BR.
* Tue Nov  1 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
